# The algorithmic differentation tool pyadjoint

The full documentation is available [here](https://pyadjoint.org)

Circle CI status: [![CircleCI](https://circleci.com/gh/dolfin-adjoint/pyadjoint.svg?style=svg)](https://circleci.com/gh/dolfin-adjoint/pyadjoint)


# Contributing

We love pull requests from everyone. 

Fork, then clone the repository at https://github.com/dolfin-adjoint/pyadjoint

Make sure the tests pass:

    py.test tests/pyadjoint

Make your change. Add tests for your change. Make the tests pass:

    py.test tests/pyadjoint

Push to your fork and [submit a pull request][pr].

[pr]: https://github.com/dolfin-adjoint/pyadjoint/pulls

At this point you're waiting on us. We may suggest
some changes or improvements or alternatives.

Some things that will increase the chance that your pull request is accepted:

* Write tests.
* Add Python docstrings that follow the [Google Style][style].
* Write good commit and pull request message.

[style]: http://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html

# Licence
This software is licensed under the [GNU LGPL v3][license].

[license]: https://github.com/dolfin-adjoint/pyadjoint/raw/master/LICENSE
